@@ -2,7 +2,7 @@ from contextvars import ContextVar, Token
 from contextlib import contextmanager
 from typing import Any, Dict, Iterator, Optional
 
-__version__ = "0.3.4"
+__version__ = "0.3.5"
 __author__ = "Tomasz Wojcik"
 
 _request_scope_context_storage: ContextVar[Dict[Any, Any]] = ContextVar(
@@ -23,10 +23,8 @@ def request_cycle_context(
     if initial_data is None:
         initial_data = {}
     token: Token = _request_scope_context_storage.set(initial_data.copy())
-    try:
-        yield
-    finally:
-        _request_scope_context_storage.reset(token)
+    yield
+    _request_scope_context_storage.reset(token)
 
 
 from starlette_context.ctx import context  # noqa: E402
