@@ -43,5 +43,19 @@ class _Context(UserDict):
 
         return copy.copy(self.data)
 
+    def __repr__(self) -> str:
+        # Opaque type to avoid default implementation
+        # that could try to look into data while out of request cycle
+        try:
+            return f"<{__name__}.{self.__class__.__name__} {self.data}>"
+        except ContextDoesNotExistError:
+            return f"<{__name__}.{self.__class__.__name__} {dict()}>"
+
+    def __str__(self):
+        try:
+            return str(self.data)
+        except ContextDoesNotExistError:
+            return str({})
+
 
 context = _Context()
